@@ -23,7 +23,6 @@ from traits.trait_base import user_name_for
 from pyface.action.action import Action
 from pyface.action.action_item import ActionItem
 from pyface.action.action_manager_item import ActionManagerItem
-import collections
 
 
 class Group(HasTraits):
@@ -157,7 +156,7 @@ class Group(HasTraits):
         """
         if isinstance(item, Action):
             item = ActionItem(action=item)
-        elif isinstance(item, collections.Callable):
+        elif callable(item):
             name = user_name_for(item.__name__)
             item = ActionItem(action=Action(name=name, on_perform=item))
 
