@@ -25,7 +25,6 @@ from traits.api import Any, Bool, Callable, Dict, Function, HasTraits, \
 # local imports
 from .grid_model import GridColumn, GridModel, GridSortEvent
 from .trait_grid_cell_adapter import TraitGridCellAdapter
-import collections
 
 # The classes below are part of the table specification.
 class TraitGridColumn(GridColumn):
@@ -391,7 +390,7 @@ class TraitGridModel(GridModel):
                formats[type(value)] is not None:
             try:
                 format = formats[type(value)]
-                if isinstance(format, collections.Callable):
+                if callable(format):
                     value = format(value)
                 else:
                     value = format % value
